SealKey constructor
SealKey(
- String name,
- Pointer<
NativeType> obj
Constructs a key referencing the underlying C obj in memory
The type and name are used to classify the type of key
Implementation
SealKey(super.name, super.obj);